@@ -84,15 +84,15 @@ function extract_installer {
 }
 
 PIP_REQUIREMENTS="\
-podcastparser==0.6.4
+podcastparser==0.6.5
 mygpoclient==1.8
 git+https://github.com/enthought/pywin32-ctypes.git@f27d6a0
 html5lib==1.0.1
 webencodings==0.5.1
 six==1.12.0
-certifi==2020.4.5.1
+certifi==2020.4.5.2
 mutagen==1.44.0
-youtube_dl==2020.3.8
+youtube_dl==2020.6.16.1
 "
 
 function install_deps {
